@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.127-17-g68d0e0d
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.128-6-g93386a5
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.128';
+our $VERSION = '0.129';
 
 use Moose;
 with
@@ -21,7 +21,7 @@ use Devel::CheckBin 'can_run';
 use Path::Tiny;
 use CPAN::Meta::Requirements;
 use Term::ANSIColor 'colored';
-eval 'require Win32::Console::ANSI' if $^O eq 'MSWin32';
+eval { +require Win32::Console::ANSI } if $^O eq 'MSWin32';
 use Config;
 use namespace::autoclean;
 
@@ -572,7 +572,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.128
+version 0.129
 
 =head1 SYNOPSIS
 
